@@ -1,7 +1,7 @@
 
 #' Bind Rows with Factors
 #' 
-#' Matches factor levels before binding rows.
+#' Matches factor levels before binding rows. If factors have 0 levels it will change the column to character to avoid errors.
 #' Author: Bryce Chamberlain.
 #'
 #' @param ... data to be binded
@@ -50,7 +50,10 @@ bindf <- function ( ..., sort.levels = TRUE){
   # bind each dataset after matching factors.
   idt = dt[[1]]
   for(i in 2:length(dt)){
-    imatch.factors = match.factors( df1 = idt, df2 = dt[[i]], sort.levels = sort.levels )
+    imatch.factors = lapply(
+      match.factors( df1 = idt, df2 = dt[[i]], sort.levels = sort.levels ), 
+      fix0levels
+    )
     idt = data.table::rbindlist( list( imatch.factors[[1]], imatch.factors[[2]] ), fill = TRUE )
   }
   
@@ -352,4 +355,15 @@ match.levels = function( factor1, factor2, sort.levels ){
   # Return the new factors.
   return( list( factor1, factor2 ) )
   
-}
\ No newline at end of file
+}
+
+fix0levels = function(x){
+  
+  for(col in 1:ncol(x)){
+    if(is.factor(x[[col]]) && length(levels(x[[col]])) == 0){
+    x[[col]] = as.character(x[[col]])
+  }}
+  
+  return(x)
+  
+}
